%bcond_with test

Summary: Security module for the Apache HTTP Server
Name: mod_security
Version: 2.9.6
Release: 8%{?dist}
License: ASL 2.0
URL: http://www.modsecurity.org/
Source0: https://github.com/SpiderLabs/ModSecurity/releases/download/v%{version}/modsecurity-%{version}.tar.gz
Source1: mod_security.conf
Source2: 10-mod_security.conf
Source3: modsecurity_localrules.conf

Patch3000: modsecurity-2.9.3-lua-54.patch
Patch3001: modsecurity-2.9.3-apulibs.patch
Patch3002: mod_security-2.9.3-remote-rules-timeout.patch

Patch0001: 0001-Fix-FILES_TMP_CONTENT-may-sometimes-lack-complete-co.patch

BuildRequires: gcc, make, autoconf, automake, libtool
BuildRequires: httpd-devel perl-generators pkgconfig(libcurl) pkgconfig(libpcre) pkgconfig(libxml-2.0)
BuildRequires: pkgconfig(lua) yajl-devel pkgconfig(uuid)

Requires: httpd httpd-mmn = %{_httpd_mmn}
Requires(pre): httpd-filesystem

%description
ModSecurity is an open source intrusion detection and prevention engine
for web applications. It operates embedded into the web server, acting
as a powerful umbrella - shielding web applications from attacks.

%package        mlogc
Summary:        ModSecurity Audit Log Collector
Requires:       mod_security
Requires(pre):  httpd-filesystem

%description mlogc
This package contains the ModSecurity Audit Log Collector.

%prep
%autosetup -p1 -n modsecurity-%{version}

%build
./autogen.sh
%configure --enable-pcre-match-limit=1000000 \
           --enable-pcre-match-limit-recursion=1000000 \
           --with-apxs=%{_httpd_apxs} \
           --with-yajl \
           --disable-static

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build

%if %{with test}
%check
make test
make test-regression
%endif

%install
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_httpd_moddir}
install -d %{buildroot}%{_sysconfdir}/httpd/modsecurity.d/
install -d %{buildroot}%{_sysconfdir}/httpd/modsecurity.d/activated_rules
install -d %{buildroot}%{_sysconfdir}/httpd/modsecurity.d/local_rules

install -m0755 apache2/.libs/mod_security2.so %{buildroot}%{_httpd_moddir}/mod_security2.so

%if "%{_httpd_modconfdir}" != "%{_httpd_confdir}"
install -Dp -m0644 %{SOURCE2} %{buildroot}%{_httpd_modconfdir}/10-mod_security.conf
install -Dp -m0644 %{SOURCE1} %{buildroot}%{_httpd_confdir}/mod_security.conf
sed  -i 's/Include/IncludeOptional/'  %{buildroot}%{_httpd_confdir}/mod_security.conf
%else
install -d -m0755 %{buildroot}%{_httpd_confdir}
cat %{SOURCE2} %{SOURCE1} > %{buildroot}%{_httpd_confdir}/mod_security.conf
%endif
install -m 700 -d %{buildroot}%{_localstatedir}/lib/%{name}

install -Dp -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/httpd/modsecurity.d/local_rules/

install -d %{buildroot}%{_localstatedir}/log/mlogc
install -d %{buildroot}%{_localstatedir}/log/mlogc/data
install -m0755 mlogc/mlogc %{buildroot}%{_bindir}/mlogc
install -m0755 mlogc/mlogc-batch-load.pl %{buildroot}%{_bindir}/mlogc-batch-load
install -m0644 mlogc/mlogc-default.conf %{buildroot}%{_sysconfdir}/mlogc.conf


%files
%license LICENSE
%doc CHANGES README.* NOTICE
%{_httpd_moddir}/mod_security2.so
%config(noreplace) %{_httpd_confdir}/*.conf
%if "%{_httpd_modconfdir}" != "%{_httpd_confdir}"
%config(noreplace) %{_httpd_modconfdir}/*.conf
%endif
%dir %{_sysconfdir}/httpd/modsecurity.d
%dir %{_sysconfdir}/httpd/modsecurity.d/activated_rules
%dir %{_sysconfdir}/httpd/modsecurity.d/local_rules
%config(noreplace) %{_sysconfdir}/httpd/modsecurity.d/local_rules/*.conf
%attr(770,apache,root) %dir %{_localstatedir}/lib/%{name}

%files mlogc
%doc mlogc/INSTALL
%attr(0640,root,apache) %config(noreplace) %{_sysconfdir}/mlogc.conf
%attr(0755,root,root) %dir %{_localstatedir}/log/mlogc
%attr(0770,root,apache) %dir %{_localstatedir}/log/mlogc/data
%attr(0755,root,root) %{_bindir}/mlogc
%attr(0755,root,root) %{_bindir}/mlogc-batch-load

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.6-8
- Rebuilt for loongarch release

* Wed Mar 6 2024 Doris Chao <doriscchao@tencent.com> - 2.9.6-7
- Add Patch0001 to fix CVE-2023-24021

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 2.9.6-6
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.6-5
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Jul 19 2023 cunshunxia <cunshunxia@tencent.com> - 2.9.6-4
- Rebuilt for httpd 2.4.57

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.6-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.6-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 15 2023 cunshunxia <cunshunxia@tencent.com> - 2.9.6-1
- initial build
